Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1545)

Unified Diff: content/browser/renderer_host/render_view_host.h

Issue 6319001: Support window.opener after a process swap. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update comments. Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_view_host.h
diff --git a/content/browser/renderer_host/render_view_host.h b/content/browser/renderer_host/render_view_host.h
index 88dac2a54ecfcf1fee99703236f06d2d57f3fc81..64d8f7927f8b1f5afa2891677c723052a12673bc 100644
--- a/content/browser/renderer_host/render_view_host.h
+++ b/content/browser/renderer_host/render_view_host.h
@@ -162,26 +162,29 @@ class RenderViewHost : public RenderWidgetHost {
void SetNavigationsSuspended(bool suspend);
// Causes the renderer to invoke the onbeforeunload event handler. The
// result will be returned via ViewMsg_ShouldClose. See also ClosePage which
// will fire the PageUnload event.
//
// Set bool for_cross_site_transition when this close is just for the current
// RenderView in the case of a cross-site transition. False means we're
// closing the entire tab.
void FirePageBeforeUnload(bool for_cross_site_transition);
+ // Tells the renderer that this RenderView is being swapped out for one in a
+ // different renderer process. The renderer should preserve the Frame object
+ // until it exits (when it has no more active RenderViews).
+ //
+ // Please see ViewMsg_SwapOut_Params in view_messages.h for a description
+ // of the parameters.
+ void SwapOut(int new_render_process_host_id, int new_request_id);
+
+ // Called by ResourceDispatcherHost after the SwapOutACK is received.
+ void OnSwapOutACK();
+
// Causes the renderer to close the current page, including running its
// onunload event handler. A ClosePage_ACK message will be sent to the
// ResourceDispatcherHost when it is finished.
- //
- // Please see ViewMsg_ClosePage in resource_messages_internal.h for a
- // description of the parameters.
- void ClosePage(bool for_cross_site_transition,
- int new_render_process_host_id,
- int new_request_id);
-
- // Called by ResourceDispatcherHost after the ClosePageACK is received.
- void OnClosePageACK(bool for_cross_site_transition);
+ void ClosePage();
// Close the page ignoring whether it has unload events registers.
// This is called after the beforeunload and unload events have fired
@@ -584,6 +587,7 @@ class RenderViewHost : public RenderWidgetHost {
void OnUpdateInspectorSetting(const std::string& key,
const std::string& value);
void OnMsgShouldCloseACK(bool proceed);
+ void OnMsgClosePageACK();
void OnAccessibilityNotifications(
const std::vector<ViewHostMsg_AccessibilityNotification_Params>& params);
@@ -162,26 +162,29 @@ class RenderViewHost : public RenderWidgetHost {
void SetNavigationsSuspended(bool suspend);
// Causes the renderer to invoke the onbeforeunload event handler. The
- // result will be returned via ViewMsg_ShouldClose. See also ClosePage which
- // will fire the PageUnload event.
+ // result will be returned via ViewMsg_ShouldClose. See also ClosePage and
+ // SwapOut, which fire the PageUnload event.
//
// Set bool for_cross_site_transition when this close is just for the current

Powered by Google App Engine
This is Rietveld 408576698